plot.biglasso: Plot coefficients from a "biglasso" object

View source: R/plot-biglasso.R

plot.biglassoR Documentation

Plot coefficients from a "biglasso" object

Description

Produce a plot of the coefficient paths for a fitted biglasso() object.

Usage

## S3 method for class 'biglasso'
plot(x, alpha = 1, log.l = TRUE, ...)

Arguments

x

Fitted biglasso() model.

alpha

Controls alpha-blending, helpful when the number of covariates is large. Default is alpha=1.

log.l

Should horizontal axis be on the log scale? Default is TRUE.

...

Other graphical parameters to plot()

Value

Invisibly returns NULL. Called for its side effect of producing a plot.

See Also

biglasso(), cv.biglasso()


biglasso documentation built on Aug. 25, 2026, 5:08 p.m.