View source: R/plot-cv-biglasso.R
| plot.cv.biglasso | R Documentation |
Plot the cross-validation curve from a cv.biglasso() object, along with standard error bars.
## S3 method for class 'cv.biglasso'
plot(
x,
log.l = TRUE,
type = c("cve", "rsq", "scale", "snr", "pred", "all"),
selected = TRUE,
vertical.line = TRUE,
col = "red",
...
)
x |
A |
log.l |
Should horizontal axis be on the log scale? Default is TRUE. |
type |
What to plot on the vertical axis. |
selected |
If |
vertical.line |
If |
col |
Controls the color of the dots (CV estimates). |
... |
Other graphical parameters to |
Error bars representing approximate 68\
estimates at value of lambda. For rsq and snr, these confidence intervals are quite crude,
especially near.
Invisibly returns NULL. Called for its side effect of producing a plot.
biglasso(), cv.biglasso()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.