Produce a plot of the coefficient paths for a fitted multiple responses mbiglasso object.
# S3 method for mbiglasso
plot(x, alpha = 1, log.l = TRUE, norm.beta = TRUE, ...)Invisibly returns NULL. Called for its side effect of producing a plot.
Fitted mbiglasso model.
Controls alpha-blending, helpful when the number of covariates is large. Default is alpha=1.
Should horizontal axis be on the log scale? Default is TRUE.
Should the vertical axis be the l2 norm of coefficients for each variable? Default is TRUE. If False, the vertical axis is the coefficients.
Other graphical parameters to plot()
biglasso()