View source: R/summary-cv-biglasso.R
| summary.cv.biglasso | R Documentation |
Summary method for cv.biglasso objects.
## S3 method for class 'cv.biglasso'
summary(object, ...)
## S3 method for class 'summary.cv.biglasso'
print(x, digits, ...)
object |
A |
... |
Further arguments passed to or from other methods. |
x |
A |
digits |
Number of digits past the decimal point to print out. Can be a vector specifying different display digits for each of the five non-integer printed values. |
summary.cv.biglasso produces an object with S3 class "summary.cv.biglasso". The
class has its own print method and contains the following list elements:
The penalty used by biglasso.
Either "linear" or "logistic", depending on the family option in biglasso.
Number of observations
Number of regression coefficients (not including the intercept).
The index of lambda with the smallest cross-validation error.
The sequence of lambda values used by cv.biglasso.
Cross-validation error (deviance).
Proportion of variance explained by the model, as estimated by cross-validation.
Signal to noise ratio, as estimated by cross-validation.
For linear regression models, the scale parameter estimate.
For logistic regression models, the prediction error (misclassification error).
biglasso(), cv.biglasso(), plot.cv.biglasso()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.