Learn R Programming

biglasso (version 1.7.2)

plot.biglasso: Plot coefficients from a "biglasso" object

Description

Produce a plot of the coefficient paths for a fitted biglasso() object.

Usage

# S3 method for biglasso
plot(x, alpha = 1, log.l = TRUE, ...)

Value

Invisibly returns NULL. Called for its side effect of producing a plot.

Arguments

x

Fitted biglasso() model.

alpha

Controls alpha-blending, helpful when the number of covariates is large. Default is alpha=1.

log.l

Should horizontal axis be on the log scale? Default is TRUE.

...

Other graphical parameters to plot()

See Also

biglasso(), cv.biglasso()