Produce a plot of the coefficient paths for a fitted biglasso() object.
# S3 method for biglasso
plot(x, alpha = 1, log.l = TRUE, ...)Invisibly returns NULL. Called for its side effect of producing a plot.
Fitted biglasso() model.
Controls alpha-blending, helpful when the number of covariates is large. Default is alpha=1.
Should horizontal axis be on the log scale? Default is TRUE.
Other graphical parameters to plot()
biglasso(), cv.biglasso()