Plots the cross-validation curve from a "cv.biglasso" object
Source:R/plot-cv-biglasso.R
plot.cv.biglasso.RdPlot the cross-validation curve from a cv.biglasso() object, along with standard error bars.
Arguments
- x
A
"cv.biglasso"object.- log.l
Should horizontal axis be on the log scale? Default is TRUE.
- type
What to plot on the vertical axis.
cveplots the cross-validation error (deviance);rsqplots an estimate of the fraction of the deviance explained by the model (R-squared);snrplots an estimate of the signal-to-noise ratio;scaleplots, forfamily="gaussian", an estimate of the scale parameter (standard deviation);predplots, forfamily="binomial", the estimated prediction error;allproduces all of the above.- selected
If
TRUE(the default), places an axis on top of the plot denoting the number of variables in the model (i.e., that have a nonzero regression coefficient) at that value oflambda.- vertical.line
If
TRUE(the default), draws a vertical line at the value where cross-validaton error is minimized.- col
Controls the color of the dots (CV estimates).
- ...
Other graphical parameters to
plot
Details
Error bars representing approximate 68\
estimates at value of lambda. For rsq and snr, these confidence intervals are quite crude,
especially near.