Plot the cross-validation curve from a cv.biglasso() object, along with standard error bars.
# S3 method for cv.biglasso
plot(
x,
log.l = TRUE,
type = c("cve", "rsq", "scale", "snr", "pred", "all"),
selected = TRUE,
vertical.line = TRUE,
col = "red",
...
)Invisibly returns NULL. Called for its side effect of producing a plot.
A "cv.biglasso" object.
Should horizontal axis be on the log scale? Default is TRUE.
What to plot on the vertical axis. cve plots the cross-validation error (deviance);
rsq plots an estimate of the fraction of the deviance explained by the model (R-squared);
snr plots an estimate of the signal-to-noise ratio; scale plots, for family="gaussian",
an estimate of the scale parameter (standard deviation); pred plots, for family="binomial",
the estimated prediction error; all produces all of the above.
If TRUE (the default), places an axis on top of the plot denoting the number of
variables in the model (i.e., that have a nonzero regression coefficient) at that value of
lambda.
If TRUE (the default), draws a vertical line at the value where
cross-validaton error is minimized.
Controls the color of the dots (CV estimates).
Other graphical parameters to plot
Error bars representing approximate 68\
estimates at value of lambda. For rsq and snr, these confidence intervals are quite crude,
especially near.
biglasso(), cv.biglasso()